==> tty2img-0.2.1.tar.gz: tty2img-0.2.1/README.md <==
About this repository
=====================

This is collection of Python packages for rendering terminal screen. It contains:

* [asciicast2movie.py](asciicast2movie.py) – script / lib for converting asciicast (v2) files to movie (e.g. mp4 file)
* [tty2img.py](tty2img.py) – lib for rendering [pyte](https://pypi.org/project/pyte/) terminal screen to image (it is needed by `asciicast2movie.py`)


## Requires

* [pyte](https://pypi.org/project/pyte/) VTXXX terminal emulator
* [PIL](https://pypi.org/project/Pillow/) image library
* [moviepy](https://pypi.org/project/moviepy/) video editing library
* [numpy](https://pypi.org/project/numpy/) array computing (for moviepy)


## License

```
Copyright © 2020, Robert Ryszard Paciorek <rrp@opcode.eu.org>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```

==> tty2img-0.3.6.tar.gz: tty2img-0.3.6/README.md <==
About this repository
=====================

This is collection of Python packages for rendering terminal screen. It contains:

* [asciicast2movie.py](asciicast2movie.py) – script / lib for converting asciicast (v2) files to movie (e.g. mp4 file)
* [tty2img.py](tty2img.py) – lib for rendering [pyte](https://pypi.org/project/pyte/) terminal screen to image (it is needed by `asciicast2movie.py`)


## Requires

* [pyte](https://pypi.org/project/pyte/) VTXXX terminal emulator
* [PIL](https://pypi.org/project/Pillow/) image library
* [moviepy](https://pypi.org/project/moviepy/) video editing library
* [numpy](https://pypi.org/project/numpy/) array computing (for moviepy)

### optional (recommended):
* [fclist-cffi](https://pypi.org/project/fclist-cffi/) fontconfig wrapper (need for support fallback fonts for missing glyphs)
* [freetype-py](https://pypi.org/project/freetype-py/) freetype wrapper (need for support fallback fonts for missing glyphs)


## License

```
Copyright © 2020, Robert Ryszard Paciorek <rrp@opcode.eu.org>

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```
